@@ -1,8 +1,9 @@
 /* GNOME-DB Components
- * Copyright (C) 2000-2002 The GNOME Foundation.
+ * Copyright (C) 2000 - 2006 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +20,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <glib/gi18n-lib.h>
 #include <gtk/gtkdialog.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtknotebook.h>
@@ -43,21 +45,26 @@ save_dsn (GnomeDbDsnConfig *props)
 	g_return_if_fail (GNOME_DB_IS_DSN_CONFIG (props));
 	dsn_info = gnome_db_dsn_config_get_info (GNOME_DB_DSN_CONFIG (props));
 	if (dsn_info) {
-		gnome_db_config_save_data_source (dsn_info->name,
-						  dsn_info->provider,
-						  dsn_info->cnc_string,
-						  dsn_info->description,
-						  dsn_info->username,
-						  dsn_info->password);
-		gnome_db_config_free_data_source_info (dsn_info);
+		gda_config_save_data_source_info (dsn_info);
+		gda_data_source_info_free (dsn_info);
 	}
 }
 
 static void
 dsn_changed_cb (GnomeDbDsnConfig *config, gpointer user_data)
 {
-	gtk_dialog_set_response_sensitive (GTK_DIALOG (user_data), REVERT_BUTTON, TRUE);
+	gboolean changed;
+	GdaDataSourceInfo *dsn_info , *old_dsn_info;
+
+	dsn_info = gnome_db_dsn_config_get_info (config);
+	old_dsn_info = g_object_get_data (G_OBJECT (user_data), "old_dsn_info");
+
+	changed = !gda_data_source_info_equal (dsn_info, old_dsn_info);
+	gtk_dialog_set_response_sensitive (GTK_DIALOG (user_data), REVERT_BUTTON, changed);
+
 	save_dsn (config);
+	if (dsn_info)
+		gda_data_source_info_free (dsn_info);
 }
 
 GdaConnection *
@@ -80,7 +87,7 @@ do_connect_dialog_for_dsn (const gchar *dsn)
 						  gnome_db_login_get_dsn (GNOME_DB_LOGIN (login)),
 						  gnome_db_login_get_username (GNOME_DB_LOGIN (login)),
 						  gnome_db_login_get_password (GNOME_DB_LOGIN (login)),
-						  0);
+						  0, NULL);
 	}
 
 	gtk_widget_destroy (dialog);
@@ -97,21 +104,21 @@ dsn_properties_dialog (GtkWindow *parent, const gchar *dsn)
 	gchar *str;
 	gint result;
 
-	old_dsn_info = gnome_db_config_find_data_source (dsn);
+	old_dsn_info = gda_config_find_data_source (dsn);
 	if (!old_dsn_info)
 		return;
 
 	/* create the dialog */
-	dialog = gtk_dialog_new_with_buttons (
-		_("Data Source Properties"),
-		parent, GTK_DIALOG_DESTROY_WITH_PARENT,
-		_("Test"), TEST_BUTTON,
-		_("Browse"), BROWSE_BUTTON,
-		GTK_STOCK_REVERT_TO_SAVED, REVERT_BUTTON,
-		GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
-		NULL);
+	dialog = gtk_dialog_new_with_buttons (_("Data Source Properties"),
+					      parent, GTK_DIALOG_DESTROY_WITH_PARENT,
+					      _("Test"), TEST_BUTTON,
+					      _("Browse"), BROWSE_BUTTON,
+					      GTK_STOCK_REVERT_TO_SAVED, REVERT_BUTTON,
+					      GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
+					      NULL);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), REVERT_BUTTON, FALSE);
+	g_object_set_data (G_OBJECT (dialog), "old_dsn_info", old_dsn_info);
 
 	icon = gdk_pixbuf_new_from_file (LIBGNOMEDB_ICONSDIR "/gnome-db.png", NULL);
 	if (icon) {
@@ -120,9 +127,16 @@ dsn_properties_dialog (GtkWindow *parent, const gchar *dsn)
 	}
 
 	/* textual explanation */
-	str = g_strdup_printf ("<b>%s:</b>\n<small>%s</small>",
-			       _("Data Source Properties"),
-			       _("Change the data source properties (the name can't be modified)"));
+	if (!old_dsn_info->is_global || gda_config_can_modify_global_config ())
+		str = g_strdup_printf ("<b>%s:</b>\n<small>%s</small>",
+				       _("Data Source Properties"),
+				       _("Change the data source properties (the name can't be modified)."));
+	else
+		str = g_strdup_printf ("<b>%s:</b>\n<small>%s</small>",
+				       _("Data Source Properties"),
+				       _("For information only, this data source is a system wide data source\n"
+					 "and you don't have the permission change it."));
+
 	label = gtk_label_new ("");
         gtk_label_set_markup (GTK_LABEL (label), str);
         gtk_misc_set_alignment (GTK_MISC (label), 0., -1);
@@ -143,6 +157,7 @@ dsn_properties_dialog (GtkWindow *parent, const gchar *dsn)
 	gtk_widget_show (props);
 	g_signal_connect (G_OBJECT (props), "changed", G_CALLBACK (dsn_changed_cb), dialog);	
 	gtk_box_pack_start (GTK_BOX (hbox), props, TRUE, TRUE, 0);
+	gtk_widget_set_size_request (props, 500, -1);
 
 	/* run the dialog */
 	do {
@@ -168,6 +183,8 @@ dsn_properties_dialog (GtkWindow *parent, const gchar *dsn)
 
 			if (gnome_db_login_dialog_run (GNOME_DB_LOGIN_DIALOG (dialog))) {
 				GtkWidget *msgdialog;
+				GError *error = NULL;
+
 				if (!db_client) 
 					db_client = gda_client_new ();
 				
@@ -175,7 +192,7 @@ dsn_properties_dialog (GtkWindow *parent, const gchar *dsn)
 								  gnome_db_login_get_dsn (GNOME_DB_LOGIN (login)),
 								  gnome_db_login_get_username (GNOME_DB_LOGIN (login)),
 								  gnome_db_login_get_password (GNOME_DB_LOGIN (login)),
-								  0);
+								  0, &error);
 				if (cnc && GDA_IS_CONNECTION (cnc)) {
 					str = g_strdup_printf ("<b>%s</b>", _("Connection successfully opened!"));
 					msgdialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (dialog), GTK_DIALOG_MODAL,
@@ -184,7 +201,13 @@ dsn_properties_dialog (GtkWindow *parent, const gchar *dsn)
 					gda_connection_close (cnc);
 				}
 				else {
-					str = g_strdup_printf ("<b>%s</b>", _("Could not open connection."));
+					if (error) {
+						str = g_strdup_printf ("<b>%s:</b>\n%s", _("Could not open connection"), 
+								       error->message ? error->message : _("Unknown error"));
+						g_error_free (error);
+					}
+					else
+						str = g_strdup_printf ("<b>%s</b>", _("Could not open connection"));
 					msgdialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (dialog), GTK_DIALOG_MODAL,
 											GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, str);
 					g_free (str);
@@ -227,5 +250,5 @@ dsn_properties_dialog (GtkWindow *parent, const gchar *dsn)
 	gtk_widget_destroy (dialog);
 
 	/* free memory */
-	gnome_db_config_free_data_source_info (old_dsn_info);
+	gda_data_source_info_free (old_dsn_info);
 }
