@@ -1,6 +1,6 @@
 /* GNOME-DB Configurator
  *
- * Copyright (C) 2000 - 2005 The GNOME Foundation.
+ * Copyright (C) 2000 - 2006 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
@@ -29,15 +29,14 @@
 #include <gtk/gtkstock.h>
 #include <gtk/gtktable.h>
 #include <gtk/gtkvbbox.h>
-#include <libgnomedb/gnome-db-grid.h>
-#include <libgnomedb/gnome-db-stock.h>
+#include <libgnomedb/libgnomedb.h>
 #include <libgnomedb/gnome-db-util.h>
-#include <libgnomedb/gnome-db-data-widget.h>
 #include "provider-config.h"
 
 #define PROVIDER_CONFIG_DATA "Provider_ConfigData"
 
 typedef struct {
+	GtkWidget *title;
 	GtkWidget *provider_list;
 } ProviderConfigPrivate;
 
@@ -64,14 +63,15 @@ show_providers (ProviderConfigPrivate *priv)
 		value_list = g_list_append (NULL, gda_value_new_string (prv_info->id));
 		value_list = g_list_append (value_list, gda_value_new_string (prv_info->description));
 
-		gda_data_model_append_values (model, (const GList *) value_list);
+		gda_data_model_append_values (model, (const GList *) value_list, NULL);
 
 		g_list_foreach (value_list, (GFunc) gda_value_free, NULL);
 		g_list_free (value_list);
 	}
+	g_object_set (G_OBJECT (model), "read_only", TRUE, NULL);
 
 	/* display the new data model */
-	gnome_db_data_widget_set_gda_model (GNOME_DB_DATA_WIDGET (priv->provider_list), NULL, model);
+	gnome_db_data_widget_set_gda_model (GNOME_DB_DATA_WIDGET (priv->provider_list), model);
 	g_object_unref (G_OBJECT (model));
 }
 
@@ -96,23 +96,29 @@ provider_config_new (void)
 	g_object_set_data_full (G_OBJECT (provider), PROVIDER_CONFIG_DATA, priv,
 				(GDestroyNotify) g_free);
 
-	table = gnome_db_new_table_widget (2, 1, FALSE);
+	table = gnome_db_new_table_widget (3, 1, FALSE);
 	gtk_box_pack_start (GTK_BOX (provider), table, TRUE, TRUE, 0);
 
-	/* create the provider list */
-	priv->provider_list = gnome_db_grid_new ();
-	gnome_db_data_widget_column_set_editable (GNOME_DB_DATA_WIDGET (priv->provider_list), 0, FALSE);
-	g_object_set (G_OBJECT (priv->provider_list), "info_cell_visible", FALSE, "actions_visible", FALSE, NULL);
-
+	/* title */
 	title = g_strdup_printf ("<b>%s</b>\n%s", _("Providers"),
 				 _("Installed providers"));
-	gnome_db_data_widget_set_title (GNOME_DB_DATA_WIDGET (priv->provider_list), title);
+	priv->title = gnome_db_gray_bar_new (title);
 	g_free (title);
+	gnome_db_gray_bar_set_icon_from_stock (GNOME_DB_GRAY_BAR (priv->title),
+					       GNOME_DB_STOCK_DATABASE, GTK_ICON_SIZE_BUTTON);
+	gtk_table_attach (GTK_TABLE (table), priv->title, 0, 1, 0, 1,
+			  GTK_FILL | GTK_SHRINK,
+			  GTK_FILL | GTK_SHRINK,
+			  0, 0);
+	gtk_widget_show (priv->title);
+
+	/* create the provider list */
+	priv->provider_list = gnome_db_raw_grid_new (NULL);
+	gnome_db_data_widget_column_set_editable (GNOME_DB_DATA_WIDGET (priv->provider_list), 0, FALSE);
+	g_object_set (G_OBJECT (priv->provider_list), "info_cell_visible", FALSE, NULL);
 
-	gnome_db_data_widget_set_show_title (GNOME_DB_DATA_WIDGET (priv->provider_list), TRUE);
-	gnome_db_data_widget_set_title_icon_from_stock (GNOME_DB_DATA_WIDGET (priv->provider_list), GNOME_DB_STOCK_DATABASE, GTK_ICON_SIZE_BUTTON);
 	gtk_widget_show (priv->provider_list);
-	gtk_table_attach (GTK_TABLE (table), priv->provider_list, 0, 1, 0, 1,
+	gtk_table_attach (GTK_TABLE (table), priv->provider_list, 0, 1, 1, 2,
 			  GTK_FILL | GTK_SHRINK | GTK_EXPAND,
 			  GTK_FILL | GTK_SHRINK | GTK_EXPAND,
 			  0, 0);
@@ -121,7 +127,7 @@ provider_config_new (void)
 	/* add tip */
 	box = gnome_db_new_hbox_widget (FALSE, 6);
         gtk_container_set_border_width (GTK_CONTAINER (box), 6);
-	gtk_table_attach (GTK_TABLE (table), box, 0, 1, 1, 2,
+	gtk_table_attach (GTK_TABLE (table), box, 0, 1, 2, 3,
 			  GTK_FILL, GTK_FILL, 0, 0);
 
 	button = gtk_image_new_from_stock (GTK_STOCK_DIALOG_INFO, GTK_ICON_SIZE_DIALOG);
@@ -149,31 +155,40 @@ void
 provider_config_select_all (GtkWidget *provider)
 {
 	ProviderConfigPrivate *priv;
+	GtkTreeSelection *sel;
 
 	priv = g_object_get_data (G_OBJECT (provider), PROVIDER_CONFIG_DATA);
-	gnome_db_grid_select_all (GNOME_DB_GRID (priv->provider_list));
+
+	sel = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->provider_list));
+
+	gtk_tree_selection_select_all (sel);
 }
 
 void
 provider_config_unselect_all (GtkWidget *provider)
 {
 	ProviderConfigPrivate *priv;
+	GtkTreeSelection *sel;
 
 	priv = g_object_get_data (G_OBJECT (provider), PROVIDER_CONFIG_DATA);
-	gnome_db_grid_unselect_all (GNOME_DB_GRID (priv->provider_list));
+
+	sel = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->provider_list));
+
+	gtk_tree_selection_unselect_all (sel);
 }
 
 gboolean
 provider_config_has_selection (GtkWidget *provider)
 {
 	ProviderConfigPrivate *priv;
-	GList *list;
-	gboolean retval;
+	GtkTreeSelection *sel;
 
 	priv = g_object_get_data (G_OBJECT (provider), PROVIDER_CONFIG_DATA);
-	list =  gnome_db_grid_get_selection (GNOME_DB_GRID (priv->provider_list));
-	retval = list == NULL ? FALSE : TRUE;
-	if (list)
-		g_list_free (list);
-	return retval;
+
+	sel = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->provider_list));
+
+	if (gtk_tree_selection_count_selected_rows (sel) >= 1)
+		return TRUE;
+	else
+		return FALSE;
 }
