@@ -1,6 +1,6 @@
 /* gnome-db-data-entry.h
  *
- * Copyright (C) 2003 Vivien Malerba
+ * Copyright (C) 2003 - 2005 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -53,7 +53,7 @@ struct _GnomeDbDataEntryIface
 	void            ( *set_value_default)     (GnomeDbDataEntry *de, const GdaValue * value);
 	void            ( *set_attributes)        (GnomeDbDataEntry *de, guint attrs, guint mask);
 	guint           ( *get_attributes)        (GnomeDbDataEntry *de);
-	GnomeDbDataHandler  *( *get_handler)           (GnomeDbDataEntry *de);
+	GdaDataHandler *( *get_handler)           (GnomeDbDataEntry *de);
 	gboolean        ( *expand_in_layout)      (GnomeDbDataEntry *de);
 };
 
@@ -75,7 +75,7 @@ void            gnome_db_data_entry_set_value_default      (GnomeDbDataEntry *de
 void            gnome_db_data_entry_set_attributes         (GnomeDbDataEntry *de, guint attrs, guint mask);
 guint           gnome_db_data_entry_get_attributes         (GnomeDbDataEntry *de);
 
-GnomeDbDataHandler  *gnome_db_data_entry_get_handler            (GnomeDbDataEntry *de);
+GdaDataHandler *gnome_db_data_entry_get_handler            (GnomeDbDataEntry *de);
 gboolean        gnome_db_data_entry_expand_in_layout       (GnomeDbDataEntry *de);
 
 G_END_DECLS
