@@ -1,6 +1,6 @@
 /* gnome-db-dbms-update-viewer.c
  *
- * Copyright (C) 2002 - 2005 Vivien Malerba
+ * Copyright (C) 2002 - 2006 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,8 +20,9 @@
 
 #include <string.h>
 #include "gnome-db-dbms-update-viewer.h"
-#include "gnome-db-server.h"
+#include <libgda/libgda.h>
 #include <gtk/gtk.h>
+#include <glib/gi18n-lib.h>
 
 static void gnome_db_dbms_update_viewer_class_init (GnomeDbmsUpdateViewerClass * class);
 static void gnome_db_dbms_update_viewer_init (GnomeDbmsUpdateViewer * wid);
@@ -30,7 +31,7 @@ static void gnome_db_dbms_update_viewer_dispose (GObject   * object);
 
 struct _GnomeDbmsUpdateViewerPriv
 {
-	GnomeDbDict *dict;
+	GdaDict     *dict;
 	GtkWidget   *table;
 	GtkWidget   *pbar;
 
@@ -88,30 +89,30 @@ gnome_db_dbms_update_viewer_init (GnomeDbmsUpdateViewer * wid)
 }
 
 static void gnome_db_dbms_update_viewer_do_init (GnomeDbmsUpdateViewer *mgv);
-static void gnome_db_dict_weak_notify (GnomeDbmsUpdateViewer *mgv, GnomeDbDict *dict);
+static void gda_dict_weak_notify (GnomeDbmsUpdateViewer *mgv, GdaDict *dict);
 /**
  * gnome_db_dbms_update_viewer_new
- * @dict: a #GnomeDbDict object
+ * @dict: a #GdaDict object
  *
  * Creates a new #GnomeDbmsUpdateViewer widget.
  *
  * Returns: the new widget
  */
 GtkWidget *
-gnome_db_dbms_update_viewer_new (GnomeDbDict *dict)
+gnome_db_dbms_update_viewer_new (GdaDict *dict)
 {
 	GObject    *obj;
 	GnomeDbmsUpdateViewer *mgv;
 
-	g_return_val_if_fail (!dict || IS_GNOME_DB_DICT (dict), NULL);
+	g_return_val_if_fail (!dict || GDA_IS_DICT (dict), NULL);
 
-	obj = g_object_new (GNOME_DB_DBMS_UPDATE_VIEWER_TYPE, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_DBMS_UPDATE_VIEWER, NULL);
 	mgv = GNOME_DB_DBMS_UPDATE_VIEWER (obj);
 
 	mgv->priv->dict = ASSERT_DICT (dict);
 
 	g_object_weak_ref (G_OBJECT (mgv->priv->dict),
-			   (GWeakNotify) gnome_db_dict_weak_notify, mgv);
+			   (GWeakNotify) gda_dict_weak_notify, mgv);
 
 	gnome_db_dbms_update_viewer_do_init (mgv);
 
@@ -119,15 +120,15 @@ gnome_db_dbms_update_viewer_new (GnomeDbDict *dict)
 }
 
 static void
-gnome_db_dict_weak_notify (GnomeDbmsUpdateViewer *mgv, GnomeDbDict *dict)
+gda_dict_weak_notify (GnomeDbmsUpdateViewer *mgv, GdaDict *dict)
 {
-	/* Tell that we don't need to weak unref the GnomeDbDict */
+	/* Tell that we don't need to weak unref the GdaDict */
 	mgv->priv->dict = NULL;
 }
 
-static void update_started_cb (GnomeDbServer *srv, GnomeDbmsUpdateViewer *mgv);
-static void update_finished_cb (GnomeDbServer *srv, GnomeDbmsUpdateViewer *mgv);
-static void update_progress_cb (GnomeDbServer *srv, gchar *key, guint now, guint total, 
+static void update_started_cb (GdaConnection *cnc, GnomeDbmsUpdateViewer *mgv);
+static void update_finished_cb (GdaConnection *cnc, GnomeDbmsUpdateViewer *mgv);
+static void update_progress_cb (GdaConnection *cnc, gchar *key, guint now, guint total, 
 				GnomeDbmsUpdateViewer *mgv);
 
 static void
@@ -140,18 +141,18 @@ gnome_db_dbms_update_viewer_dispose (GObject *object)
 	mgv = GNOME_DB_DBMS_UPDATE_VIEWER (object);
 
 	if (mgv->priv) {
-		/* Weak unref the GnomeDbDict is necessary */
+		/* Weak unref the GdaDict is necessary */
 		if (mgv->priv->dict) {
-			GnomeDbServer *srv = gnome_db_dict_get_server (mgv->priv->dict);
-			GnomeDbDatabase *db = gnome_db_dict_get_database (mgv->priv->dict);
+			GdaConnection *cnc = gda_dict_get_connection (mgv->priv->dict);
+			GdaDictDatabase *db = gda_dict_get_database (mgv->priv->dict);
 			g_object_weak_unref (G_OBJECT (mgv->priv->dict),
-					     (GWeakNotify) gnome_db_dict_weak_notify, mgv);
+					     (GWeakNotify) gda_dict_weak_notify, mgv);
 
-			g_signal_handlers_disconnect_by_func (G_OBJECT (srv),
+			g_signal_handlers_disconnect_by_func (G_OBJECT (mgv->priv->dict),
 							      G_CALLBACK (update_started_cb), mgv);
-			g_signal_handlers_disconnect_by_func (G_OBJECT (srv), 
+			g_signal_handlers_disconnect_by_func (G_OBJECT (mgv->priv->dict), 
 							      G_CALLBACK (update_finished_cb), mgv);
-			g_signal_handlers_disconnect_by_func (G_OBJECT (srv),
+			g_signal_handlers_disconnect_by_func (G_OBJECT (mgv->priv->dict),
 							      G_CALLBACK (update_progress_cb), mgv);
 			g_signal_handlers_disconnect_by_func (G_OBJECT (db),
 							      G_CALLBACK (update_started_cb), mgv);
@@ -189,8 +190,8 @@ static void
 gnome_db_dbms_update_viewer_do_init (GnomeDbmsUpdateViewer *mgv)
 {
 	GtkWidget *table, *pbar;
-	GnomeDbServer *srv;
-	GnomeDbDatabase *db;
+	GdaConnection *cnc;
+	GdaDictDatabase *db;
 
 	gtk_container_set_border_width (GTK_CONTAINER (mgv), 5);
 
@@ -222,15 +223,14 @@ gnome_db_dbms_update_viewer_do_init (GnomeDbmsUpdateViewer *mgv)
 
 	gnome_db_dbms_update_viewer_reset (mgv);
 
-	srv = gnome_db_dict_get_server (mgv->priv->dict);
-	g_signal_connect (G_OBJECT (srv), "data_update_started",
+	g_signal_connect (G_OBJECT (mgv->priv->dict), "data_update_started",
 			  G_CALLBACK (update_started_cb), mgv);
-	g_signal_connect (G_OBJECT (srv), "data_update_finished",
+	g_signal_connect (G_OBJECT (mgv->priv->dict), "data_update_finished",
 			  G_CALLBACK (update_finished_cb), mgv);
-	g_signal_connect (G_OBJECT (srv), "update_progress",
+	g_signal_connect (G_OBJECT (mgv->priv->dict), "update_progress",
 			  G_CALLBACK (update_progress_cb), mgv);
 
-	db = gnome_db_dict_get_database (mgv->priv->dict);
+	db = gda_dict_get_database (mgv->priv->dict);
 	g_signal_connect (G_OBJECT (db), "data_update_started",
 			  G_CALLBACK (update_started_cb), mgv);
 	g_signal_connect (G_OBJECT (db), "data_update_finished",
@@ -306,14 +306,14 @@ static void gnome_db_dbms_update_viewer_do_reset (GnomeDbmsUpdateViewer *mgv, gb
 
 
 static void
-update_started_cb (GnomeDbServer *srv, GnomeDbmsUpdateViewer *mgv)
+update_started_cb (GdaConnection *cnc, GnomeDbmsUpdateViewer *mgv)
 {
 	gnome_db_dbms_update_viewer_do_reset (mgv, FALSE);
 	gtk_widget_set_sensitive (GTK_WIDGET (mgv), TRUE);
 }
 
 static void
-update_finished_cb (GnomeDbServer *srv, GnomeDbmsUpdateViewer *mgv)
+update_finished_cb (GdaConnection *cnc, GnomeDbmsUpdateViewer *mgv)
 {
 	if (mgv->priv->current_key) {
 		g_free (mgv->priv->current_key);
@@ -323,7 +323,7 @@ update_finished_cb (GnomeDbServer *srv, GnomeDbmsUpdateViewer *mgv)
 }
 
 static void
-update_progress_cb (GnomeDbServer *srv, gchar *key, guint now, guint total, GnomeDbmsUpdateViewer *mgv)
+update_progress_cb (GdaConnection *cnc, gchar *key, guint now, guint total, GnomeDbmsUpdateViewer *mgv)
 {
 	GtkWidget *table = mgv->priv->table;
 	GtkWidget *pbar = mgv->priv->pbar;
