@@ -24,6 +24,8 @@
 #include <string.h>
 #include <libgda/gda-client.h>
 #include <libgda/gda-config.h>
+#include <libgda/gda-parameter-list.h>
+#include <libgda/gda-parameter.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <libgnomeui/gnome-druid-page-edge.h>
 #include <libgnomeui/gnome-druid-page-standard.h>
@@ -31,16 +33,15 @@
 #include <libgnomedb/gnome-db-dsn-spec.h>
 #include <libgnomedb/gnome-db-provider-selector.h>
 #include <libgnomedb/gnome-db-util.h>
-#include <libgnomedb/gnome-db-data-set.h>
-#include <libgnomedb/gnome-db-parameter.h>
 #include <libgnomedb/gnome-db-basic-form.h>
 #include <glib/gi18n-lib.h>
 
 #define PARENT_TYPE GNOME_TYPE_DRUID
 
 struct _GnomeDbDsnConfigDruidPrivate {
-	GdaClient *client;
+	GdaClient         *client;
 	GdaDataSourceInfo *dsn_info;
+	GdaParameterList  *paramlist;
 
 	GdkPixbuf *logo;
 
@@ -128,91 +129,63 @@ druid_finished_cb (GnomeDruidPage *druid_page, GtkWidget *druid_widget, GnomeDbD
 
 	/* New database creation first */
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (druid->priv->choose_toggle))) {
-		/* make a list of GdaParameter parameters */
-		GnomeDbDataSet *dset;
-
-		dset = gnome_db_basic_form_get_data_set (GNOME_DB_BASIC_FORM (druid->priv->newdb_params));
-		if (!dset) 
-			return;
-
-		if (!gnome_db_data_set_is_valid (dset)) {
+		if (!gda_parameter_list_is_valid (druid->priv->paramlist)) {
 			gnome_db_show_error (NULL, _("Missing mandatory informmation, to create database"));
 			gnome_druid_set_page (GNOME_DRUID (druid), GNOME_DRUID_PAGE (druid->priv->newdb_page));
 			return;
 		}
 		else {
-			GdaParameterList *plist = NULL;
-			GSList *params;
-			GdaParameter *gda_param;
-			GnomeDbParameter *param;
-			gchar *str;
-			GError *error = NULL;
-			GList *dsn_params;
-
+			GSList *params;	
 			GdaProviderInfo *prov_info;
+			GSList *dsn_params;
+			GError *error = NULL;
 
-			params = dset->parameters;
+			params = druid->priv->paramlist->parameters;
 			while (params) {
-				param = GNOME_DB_PARAMETER (params->data);
-				gda_param = gda_parameter_new_from_value ("", gnome_db_parameter_get_value (param));
-				g_object_get (G_OBJECT (param), "string_id", &str, NULL);
-				if (str) {
-					gda_parameter_set_name (gda_param, str);
-					g_free (str);
-				}
-				else
-					gda_parameter_set_name (gda_param, gnome_db_base_get_name (GNOME_DB_BASE (param)));	
-				if (!plist)
-					plist = gda_parameter_list_new ();
-				gda_parameter_list_add_parameter (plist, gda_param);
-
+				gda_object_set_name (GDA_OBJECT (params->data), gda_object_get_id (GDA_OBJECT (params->data)));
 				params = g_slist_next (params);
 			}
-
+			
 			allok = gda_client_create_database (druid->priv->client, 
 							    gnome_db_provider_selector_get_selected_provider (
 								    GNOME_DB_PROVIDER_SELECTOR (druid->priv->general_provider)),
-							    plist, &error);
+							    druid->priv->paramlist, &error);
 			if (!allok) {
+				gchar *str;
 				str = g_strdup_printf (_("Error creating database: %s"), 
 						       error && error->message ? error->message : _("Unknown error"));
 				gnome_db_show_error (NULL, str);
 				g_free (str);
-
+				
 				gnome_druid_set_page (GNOME_DRUID (druid), GNOME_DRUID_PAGE (druid->priv->newdb_page));
-				gda_parameter_list_free (plist);
 				return;
 			}
-
+			
 			/* make the connection string for the data source */
 			prov_info = gda_config_get_provider_by_name (gnome_db_provider_selector_get_selected_provider (
 									     GNOME_DB_PROVIDER_SELECTOR (druid->priv->general_provider)));
 			g_return_if_fail (prov_info);
-			dsn_params = prov_info->gda_params;
+			dsn_params = prov_info->gda_params->parameters;
 			while (dsn_params) {
-				GdaParameter *param;
+				GdaParameter *param = GDA_PARAMETER (dsn_params->data);				
+				const GdaValue *value;
+				
+				value = gda_parameter_get_value (param);
+				if (value && !gda_value_is_null ((GdaValue *) value)) {
+					gchar *str;
 
-				param = gda_parameter_list_find (plist, ((GdaProviderParameterInfo*)(dsn_params->data))->name);
-				if (param) {
-					const GdaValue *value;
-
-					value = gda_parameter_get_value (param);
-					if (value && !gda_value_is_null (value)) {
-						if (dsn_params == prov_info->gda_params)
-							cnc_string = g_string_new ("");
-						else
-							g_string_append (cnc_string, "; ");
-						str = gda_value_stringify (value);
-						g_string_append_printf (cnc_string, "%s=%s", 
-									((GdaProviderParameterInfo*)(dsn_params->data))->name, str);
-						g_free (str);
-					}
+					if (dsn_params == prov_info->gda_params->parameters)
+						cnc_string = g_string_new ("");
+					else
+						g_string_append (cnc_string, "; ");
+					str = gda_value_stringify ((GdaValue *) value);
+					g_string_append_printf (cnc_string, "%s=%s",
+								gda_object_get_name (GDA_OBJECT (param)), str);
+					g_free (str);
 				}
-
-				dsn_params = g_list_next (dsn_params);
+				
+				dsn_params = g_slist_next (dsn_params);
 			}
-
-			gda_parameter_list_free (plist);
 		}
 	}
 
@@ -373,15 +346,15 @@ choose_next_pressed_cb (GnomeDruidPage *druid_page,
 						             GNOME_DB_PROVIDER_SELECTOR (druid->priv->general_provider)),
 						             GDA_CLIENT_SPECS_CREATE_DATABASE);
 			if (str) {
-				GnomeDbDataSet *dset;
+				GdaParameterList *dset;
 				GError *error = NULL;
 				
-				dset = GNOME_DB_DATA_SET (gnome_db_data_set_new_from_spec (NULL, str, &error));
+				dset = GDA_PARAMETER_LIST (gda_parameter_list_new_from_spec (NULL, str, &error));
 				if (dset) {
-					druid->priv->newdb_params = gnome_db_basic_form_new (NULL, dset);
+					druid->priv->paramlist = dset;
+					druid->priv->newdb_params = gnome_db_basic_form_new (dset);
 					gnome_db_basic_form_show_entries_actions (GNOME_DB_BASIC_FORM (druid->priv->newdb_params),
 										  FALSE);
-					g_object_unref (dset);
 				}
 				else {
 					gchar *str2;
@@ -705,6 +678,9 @@ gnome_db_dsn_config_druid_finalize (GObject *object)
 	if (druid->priv->create_db_spec)
 		g_free (druid->priv->create_db_spec);
 
+	if (druid->priv->paramlist)
+		g_object_unref (druid->priv->paramlist);
+
 	g_free (druid->priv);
 	druid->priv = NULL;
 
