@@ -1,5 +1,5 @@
 /* GNOME DB library
- * Copyright (C) 1999 - 2005 The GNOME Foundation.
+ * Copyright (C) 1999 - 2006 The GNOME Foundation.
  *
  * AUTHORS:
  * 	Rodrigo Moya <rodrigo@gnome-db.org>
@@ -21,6 +21,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <gtk/gtk.h>
+#include <glib/gi18n-lib.h>
 #ifdef HAVE_LIBGLADE
 #include <glade/glade-init.h>
 #endif
@@ -28,28 +30,9 @@
 #ifdef BUILD_WITH_GNOME
 #include <libgnomeui/gnome-ui-init.h>
 #endif
-#include <libgnomedb/libgnomedb.h>
 #include <gconf/gconf-client.h>
 
 extern void gnome_db_stock_init (void);
-GnomeDbDict *default_dict = NULL; /* available in all libgnomedb, anways NOT NULL */
-
-/*
- * Public functions
- */
-
-/**
- * gnome_db_get_default_dict
- *
- * Get the default dictionary.
- *
- * Returns: a not %NULL pointer to the default #GnomeDbDict dictionary
- */
-GnomeDbDict *
-gnome_db_get_default_dict (void)
-{
-	return default_dict;
-}
 
 /**
  * gnome_db_init
@@ -70,7 +53,7 @@ gnome_db_init (const gchar *app_id, const gchar *version, gint nargs, gchar *arg
 		return;
 	}
 
-	bindtextdomain(GETTEXT_PACKAGE, LIBGNOMEDB_LOCALEDIR);
+	bindtextdomain (GETTEXT_PACKAGE, LIBGNOMEDB_LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
 	gda_init (app_id, version, nargs, args);
@@ -91,8 +74,8 @@ gnome_db_init (const gchar *app_id, const gchar *version, gint nargs, gchar *arg
 	/* init GConf */
 	if (!gconf_is_initialized ())
 		gconf_init (0, NULL, NULL);
-	
-	default_dict = GNOME_DB_DICT (gnome_db_dict_new ());
+
+	initialized = TRUE;
 }
 
 typedef struct {
