@@ -1,6 +1,6 @@
 /* gnome-db-canvas-entity.c
  *
- * Copyright (C) 2002 - 2005 Vivien Malerba
+ * Copyright (C) 2002 - 2006 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -19,28 +19,24 @@
  */
 
 #include <gtk/gtk.h>
+#include <libgda/libgda.h>
 #include "gnome-db-canvas.h"
 #include "gnome-db-canvas-entity.h"
 #include "gnome-db-canvas-field.h"
-#include <libgnomedb/gnome-db-field.h>
-#include <libgnomedb/gnome-db-table.h>
-#include <libgnomedb/gnome-db-query.h>
-#include <libgnomedb/gnome-db-entity.h>
-#include <libgnomedb/gnome-db-target.h>
 
 static void gnome_db_canvas_entity_class_init (GnomeDbCanvasEntityClass * class);
 static void gnome_db_canvas_entity_init       (GnomeDbCanvasEntity * drag);
 static void gnome_db_canvas_entity_dispose    (GObject   * object);
 static void gnome_db_canvas_entity_finalize   (GObject   * object);
 
-static void gnome_db_canvas_entity_set_property (GObject              *object,
-					   guint                 param_id,
-					   const GValue         *value,
-					   GParamSpec           *pspec);
-static void gnome_db_canvas_entity_get_property (GObject              *object,
-					   guint                 param_id,
-					   GValue               *value,
-					   GParamSpec           *pspec);
+static void gnome_db_canvas_entity_set_property (GObject *object,
+					   guint param_id,
+					   const GValue *value,
+					   GParamSpec *pspec);
+static void gnome_db_canvas_entity_get_property (GObject *object,
+					   guint param_id,
+					   GValue *value,
+					   GParamSpec *pspec);
 
 enum
 {
@@ -53,8 +49,8 @@ enum
 
 struct _GnomeDbCanvasEntityPrivate
 {
-	GnomeDbTarget           *target; /* NULL if the GnomeDbCanvasEntity is a generic entity */
-	GnomeDbEntity           *entity;
+	GdaQueryTarget           *target; /* NULL if the GnomeDbCanvasEntity is a generic entity */
+	GdaEntity           *entity;
 
 	/* UI building information */
         GSList             *field_items; /* list of GnomeCanvasItem for the fields */
@@ -141,8 +137,8 @@ gnome_db_canvas_entity_init (GnomeDbCanvasEntity * entity)
 
 static void clean_items (GnomeDbCanvasEntity *ce);
 static void create_items (GnomeDbCanvasEntity *ce);
-static void object_nullified_cb (GnomeDbEntity *ent, GnomeDbCanvasEntity *ce);
-static void entity_changed_cb (GnomeDbEntity *ent, GnomeDbCanvasEntity *ce);
+static void object_destroyed_cb (GdaEntity *ent, GnomeDbCanvasEntity *ce);
+static void entity_changed_cb (GdaEntity *ent, GnomeDbCanvasEntity *ce);
 
 static void
 gnome_db_canvas_entity_dispose (GObject   * object)
@@ -155,12 +151,12 @@ gnome_db_canvas_entity_dispose (GObject   * object)
 	clean_items (ce);
 	if (ce->priv->target) {
 		g_signal_handlers_disconnect_by_func (G_OBJECT (ce->priv->target),
-						      G_CALLBACK (object_nullified_cb), ce);
+						      G_CALLBACK (object_destroyed_cb), ce);
 		ce->priv->target = NULL;
 	}
 	if (ce->priv->entity) {
 		g_signal_handlers_disconnect_by_func (G_OBJECT (ce->priv->entity),
-						      G_CALLBACK (object_nullified_cb), ce);
+						      G_CALLBACK (object_destroyed_cb), ce);
 		g_signal_handlers_disconnect_by_func (G_OBJECT (ce->priv->entity),
 						      G_CALLBACK (entity_changed_cb), ce);
 		ce->priv->entity = NULL;
@@ -194,10 +190,10 @@ gnome_db_canvas_entity_finalize (GObject   * object)
 }
 
 static void 
-gnome_db_canvas_entity_set_property    (GObject              *object,
-				  guint                 param_id,
-				  const GValue         *value,
-				  GParamSpec           *pspec)
+gnome_db_canvas_entity_set_property    (GObject *object,
+				  guint param_id,
+				  const GValue *value,
+				  GParamSpec *pspec)
 {
 	GnomeDbCanvasEntity *ce;
 	gpointer ptr;
@@ -215,15 +211,15 @@ gnome_db_canvas_entity_set_property    (GObject              *object,
 
 		if (ce->priv->target) {
 			g_signal_handlers_disconnect_by_func (G_OBJECT (ce->priv->target),
-							      G_CALLBACK (object_nullified_cb), ce);
+							      G_CALLBACK (object_destroyed_cb), ce);
 			g_object_set (G_OBJECT (object), "entity", NULL, NULL);
 			ce->priv->target = NULL;
 		}
 		if (ptr) {
-			g_return_if_fail (IS_GNOME_DB_TARGET (ptr));
-			ce->priv->target = GNOME_DB_TARGET (ptr);
-			gnome_db_base_connect_nullify (ce->priv->target, G_CALLBACK (object_nullified_cb), ce);
-			g_object_set (G_OBJECT (object), "entity", gnome_db_target_get_represented_entity (GNOME_DB_TARGET (ptr)), NULL);
+			g_return_if_fail (GDA_IS_QUERY_TARGET (ptr));
+			ce->priv->target = GDA_QUERY_TARGET (ptr);
+			gda_object_connect_destroy (ce->priv->target, G_CALLBACK (object_destroyed_cb), ce);
+			g_object_set (G_OBJECT (object), "entity", gda_query_target_get_represented_entity (GDA_QUERY_TARGET (ptr)), NULL);
 		}
 		break;
 	case PROP_ENTITY:
@@ -233,16 +229,16 @@ gnome_db_canvas_entity_set_property    (GObject              *object,
 
 		if (ce->priv->entity) {
 			g_signal_handlers_disconnect_by_func (G_OBJECT (ce->priv->entity),
-							      G_CALLBACK (object_nullified_cb), ce);
+							      G_CALLBACK (object_destroyed_cb), ce);
 			g_signal_handlers_disconnect_by_func (G_OBJECT (ce->priv->entity),
 							      G_CALLBACK (entity_changed_cb), ce);
 			ce->priv->entity = NULL;
 			clean_items (ce);
 		}
 		if (ptr) {
-			g_return_if_fail (IS_GNOME_DB_ENTITY (ptr));
+			g_return_if_fail (GDA_IS_ENTITY (ptr));
 			ce->priv->entity = ptr;
-			gnome_db_base_connect_nullify (ce->priv->entity, G_CALLBACK (object_nullified_cb), ce);
+			gda_object_connect_destroy (ce->priv->entity, G_CALLBACK (object_destroyed_cb), ce);
 			/* Signals to keep the display up to date */
 			g_signal_connect (G_OBJECT (ce->priv->entity), "changed",
 					  G_CALLBACK (entity_changed_cb), ce);
@@ -271,20 +267,20 @@ gnome_db_canvas_entity_set_property    (GObject              *object,
 }
 
 static void 
-gnome_db_canvas_entity_get_property    (GObject              *object,
-				    guint                 param_id,
-				    GValue               *value,
-				    GParamSpec           *pspec)
+gnome_db_canvas_entity_get_property    (GObject *object,
+				    guint param_id,
+				    GValue *value,
+				    GParamSpec *pspec)
 {
 	TO_IMPLEMENT;
 }
 
 static void
-object_nullified_cb (GnomeDbEntity *ent, GnomeDbCanvasEntity *ce)
+object_destroyed_cb (GdaEntity *ent, GnomeDbCanvasEntity *ce)
 {
 	if ((ent == ce->priv->entity) && ce->priv->target) {
 		g_signal_handlers_disconnect_by_func (G_OBJECT (ce->priv->entity),
-						      G_CALLBACK (object_nullified_cb), ce);
+						      G_CALLBACK (object_destroyed_cb), ce);
 		g_signal_handlers_disconnect_by_func (G_OBJECT (ce->priv->entity),
 						      G_CALLBACK (entity_changed_cb), ce);
 		ce->priv->entity = NULL;
@@ -294,7 +290,7 @@ object_nullified_cb (GnomeDbEntity *ent, GnomeDbCanvasEntity *ce)
 }
 
 static void
-entity_changed_cb (GnomeDbEntity *ent, GnomeDbCanvasEntity *ce)
+entity_changed_cb (GdaEntity *ent, GnomeDbCanvasEntity *ce)
 {
 	create_items (ce);
 }
@@ -328,7 +324,7 @@ static void
 create_items (GnomeDbCanvasEntity *ce)
 {
 	GnomeCanvasItem *item;
-	const gchar *cstr, *cstr2;
+	const gchar *cstr;
 	gchar *tmpstr = NULL;
 	double x1, y1, x2, y2;
 	GSList *list, *tmplist;
@@ -349,9 +345,9 @@ create_items (GnomeDbCanvasEntity *ce)
 		(GTK_WIDGET (GNOME_CANVAS_ITEM (ce)->canvas)->style->font_desc);
 
 	if (ce->priv->target)
-		tmpstr = gnome_db_target_get_complete_name (ce->priv->target);
+		tmpstr = gda_query_target_get_complete_name (ce->priv->target);
 	else {
-		cstr = gnome_db_base_get_name (GNOME_DB_BASE (ce->priv->entity));
+		cstr = gda_object_get_name (GDA_OBJECT (ce->priv->entity));
 		tmpstr = g_strdup (cstr);
 	}
 		
@@ -377,7 +373,7 @@ create_items (GnomeDbCanvasEntity *ce)
 
 	/* fields */
 	sqsize = title_text_height * 0.6;
-	list = gnome_db_entity_get_fields (ce->priv->entity);
+	list = gda_entity_get_fields (ce->priv->entity);
 
 	ce->priv->field_ypos = g_new0 (gdouble, g_slist_length (list) + 1);
 	ce->priv->field_ypos [0] = title_text_height + 3* ce->priv->y_text_space;
@@ -408,9 +404,9 @@ create_items (GnomeDbCanvasEntity *ce)
 	g_slist_free (list);
 
 	cstr = GNOME_DB_CANVAS_ENTITY_COLOR;
-	if (IS_GNOME_DB_TABLE (ce->priv->entity))
+	if (GDA_IS_DICT_TABLE (ce->priv->entity))
 		cstr = GNOME_DB_CANVAS_DB_TABLE_COLOR;
-	if (IS_GNOME_DB_QUERY (ce->priv->entity))
+	if (GDA_IS_QUERY (ce->priv->entity))
 		cstr = GNOME_DB_CANVAS_QUERY_COLOR;
 
 	/* "button" to activate a popup menu the GnomeDbCanvasEntity  */
@@ -526,7 +522,7 @@ button_item_event (GnomeCanvasItem *ci, GdkEvent *event, GnomeDbCanvasEntity *ce
 /**
  * gnome_db_canvas_entity_get_field_item
  * @ce: a #GnomeDbCanvasEntity object
- * @field: a #GnomeDbField object
+ * @field: a #GdaEntityField object
  *
  * Get the #GnomeDbCanvasField object representing @field
  * in @ce.
@@ -534,7 +530,7 @@ button_item_event (GnomeCanvasItem *ci, GdkEvent *event, GnomeDbCanvasEntity *ce
  * Returns: the corresponding #GnomeDbCanvasField
  */
 GnomeDbCanvasField *
-gnome_db_canvas_entity_get_field_item (GnomeDbCanvasEntity *ce, GnomeDbField *field)
+gnome_db_canvas_entity_get_field_item (GnomeDbCanvasEntity *ce, GdaEntityField *field)
 {
 	GSList *fields;
 	gint pos;
@@ -543,7 +539,7 @@ gnome_db_canvas_entity_get_field_item (GnomeDbCanvasEntity *ce, GnomeDbField *fi
 	g_return_val_if_fail (ce->priv, NULL);
 	g_return_val_if_fail (ce->priv->entity, NULL);
 
-	fields = gnome_db_entity_get_fields (ce->priv->entity);
+	fields = gda_entity_get_fields (ce->priv->entity);
 	pos = g_slist_index (fields, field);
 	g_return_val_if_fail (pos >= 0, NULL);
 
@@ -554,7 +550,7 @@ gnome_db_canvas_entity_get_field_item (GnomeDbCanvasEntity *ce, GnomeDbField *fi
 /**
  * gnome_db_canvas_entity_get_field_ypos
  * @ce: a #GnomeDbCanvasEntity object
- * @field: a #GnomeDbField object
+ * @field: a #GdaEntityField object
  *
  * Get the Y position of the middle of the #GnomeDbCanvasField object representing @field
  * in @ce, in @ce's coordinates.
@@ -562,7 +558,7 @@ gnome_db_canvas_entity_get_field_item (GnomeDbCanvasEntity *ce, GnomeDbField *fi
  * Returns: the Y coordinate.
  */
 gdouble
-gnome_db_canvas_entity_get_field_ypos (GnomeDbCanvasEntity *ce, GnomeDbField *field)
+gnome_db_canvas_entity_get_field_ypos (GnomeDbCanvasEntity *ce, GdaEntityField *field)
 {
 	gint pos;
 
@@ -571,7 +567,7 @@ gnome_db_canvas_entity_get_field_ypos (GnomeDbCanvasEntity *ce, GnomeDbField *fi
 	g_return_val_if_fail (ce->priv->entity, 0.);
 	g_return_val_if_fail (ce->priv->field_ypos, 0.);
 
-	pos = gnome_db_entity_get_field_index (ce->priv->entity, field);
+	pos = gda_entity_get_field_index (ce->priv->entity, field);
 	g_return_val_if_fail (pos >= 0, 0.);
 	return (0.75 * ce->priv->field_ypos[pos+1] + 0.25 * ce->priv->field_ypos[pos]);
 }
