@@ -1,6 +1,6 @@
 /* sel-onequery.c
  *
- * Copyright (C) 2004 Vivien Malerba
+ * Copyright (C) 2004 - 2006 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -19,23 +19,14 @@
  */
 
 #include "sel-onequery.h"
-#include <libgnomedb/libgnomedb.h>
-#include "gnome-db-query.h"
-#include "gnome-db-entity.h"
-#include "gnome-db-qfield.h"
-#include "gnome-db-field.h"
-#include "gnome-db-renderer.h"
-#include "gnome-db-server-data-type.h"
-#include "gnome-db-qf-all.h"
-#include "gnome-db-qf-field.h"
-#include "gnome-db-qf-value.h"
-#include "gnome-db-qf-func.h"
-#include "gnome-db-target.h"
+#include <libgda/libgda.h>
+#include <glib/gi18n-lib.h>
+#include "gnome-db-stock.h"
 #include "sel-onetarget.h"
 
 /*
  *
- * Modules for the fields, targets, joins, etc of a given GnomeDbQuery
+ * Modules for the fields, targets, joins, etc of a given GdaQuery
  *
  */
 typedef struct {
@@ -50,25 +41,25 @@ static const gchar *module_onequery_col_name (Module *module, guint colno);
 static Module      *module_onequery_obj_manager (Module *module, GtkTreeIter *iter, GObject *object);
 static void         module_onequery_model_store_data (Module *module, GtkTreeIter *iter);
 static GSList      *module_onequery_get_objects_list (Module *module);
-static const gchar *module_onequery_render_qfield_type (GnomeDbQfield *field);
+static const gchar *module_onequery_render_qfield_type (GdaQueryField *field);
 
 Module *
 sel_module_onequery_new (GnomeDbSelector *mgsel, gboolean insert_header, 
 			 GtkTreeIter *iter, gpointer data)
 {
 	Module *module;
-	GnomeDbQuery *query;
+	GdaQuery *query;
 	GdkPixbuf *pixbuf_query = NULL;
 	GdkPixbuf *pixbuf_field = NULL;
 	GdkPixbuf *pixbuf_target = NULL;
 
-	g_assert (data && IS_GNOME_DB_QUERY (data));
-	pixbuf_query = gnome_db_stock_get_icon_pixbuf_file ("gnome-db-query_16x16.png");
-	pixbuf_field = gnome_db_stock_get_icon_pixbuf_file ("gnome-db-field_16x16.png");
-	pixbuf_target = gnome_db_stock_get_icon_pixbuf_file ("gnome-db-table_16x16.png");
+	g_assert (data && GDA_IS_QUERY (data));
+	pixbuf_query = gnome_db_stock_get_icon_pixbuf_file ("gda-query_16x16.png");
+	pixbuf_field = gnome_db_stock_get_icon_pixbuf_file ("gda-entity-field_16x16.png");
+	pixbuf_target = gnome_db_stock_get_icon_pixbuf_file ("gda-dict-table_16x16.png");
 
 	/* module structure */
-	query = GNOME_DB_QUERY (data);
+	query = GDA_QUERY (data);
 	module = g_new0 (Module, 1);
 	module->selector = mgsel;
 	module->fill_model = module_onequery_fill_model;
@@ -91,7 +82,7 @@ sel_module_onequery_new (GnomeDbSelector *mgsel, gboolean insert_header,
 	FLAT_DATA (module)->get_objects_list = module_onequery_get_objects_list;
 	QUERY_DATA (module)->field_pixbuf = pixbuf_field;
 
-	g_hash_table_insert (FLAT_DATA (module)->pixbuf_hash, GUINT_TO_POINTER (GNOME_DB_TYPE_TARGET), pixbuf_target);
+	g_hash_table_insert (FLAT_DATA (module)->pixbuf_hash, GUINT_TO_POINTER (GDA_TYPE_QUERY_TARGET), pixbuf_target);
 
 	/* model settings */
 	if (insert_header) {
@@ -101,7 +92,7 @@ sel_module_onequery_new (GnomeDbSelector *mgsel, gboolean insert_header,
 		module->iter = g_new0 (GtkTreeIter, 1);
 		gtk_tree_store_append (GTK_TREE_STORE (model), module->iter, iter);
 		gtk_tree_store_set (GTK_TREE_STORE (model), module->iter, 
-				    NAME_COLUMN, gnome_db_base_get_name (GNOME_DB_BASE (query)), 
+				    NAME_COLUMN, gda_object_get_name (GDA_OBJECT (query)), 
 				    PIXBUF_COLUMN, pixbuf, 
 				    CONTENTS_COLUMN, CONTENTS_TOP_CATEGORY, 
 				    SUB_MODULE_COLUMN, NULL, -1);
@@ -165,18 +156,18 @@ module_onequery_get_objects_list (Module *module)
 	GSList *tmplist;
 
 	g_return_val_if_fail (FLAT_DATA (module)->manager, NULL);
-	g_return_val_if_fail (IS_GNOME_DB_QUERY (FLAT_DATA (module)->manager), NULL);
+	g_return_val_if_fail (GDA_IS_QUERY (FLAT_DATA (module)->manager), NULL);
 
 	/* sub queries first, if applicable */
 	if (module->selector->priv->mode & GNOME_DB_SELECTOR_SUB_QUERIES) 
 		retval = g_slist_concat (retval, 
-					 gnome_db_query_get_sub_queries (GNOME_DB_QUERY (FLAT_DATA (module)->manager)));
+					 gda_query_get_sub_queries (GDA_QUERY (FLAT_DATA (module)->manager)));
 
 	/* targets, if applicable */
 	if ((module->selector->priv->mode & GNOME_DB_SELECTOR_TARGETS) ||
 	    (module->selector->priv->mode & GNOME_DB_SELECTOR_TARGETS_CTS))
 		retval = g_slist_concat (retval, 
-					 gnome_db_query_get_targets (GNOME_DB_QUERY (FLAT_DATA (module)->manager)));
+					 gda_query_get_targets (GDA_QUERY (FLAT_DATA (module)->manager)));
 
 	/* fields, if applicable.
 	 * note: if targets are shown then the fields "belonging" to the targets
@@ -184,15 +175,15 @@ module_onequery_get_objects_list (Module *module)
 	if (!(module->selector->priv->mode & GNOME_DB_SELECTOR_TARGETS_CTS)) {
 		tmplist = NULL;
 		if (module->selector->priv->mode & GNOME_DB_SELECTOR_QVIS_FIELDS)
-			tmplist = gnome_db_entity_get_fields (GNOME_DB_ENTITY (FLAT_DATA (module)->manager));
+			tmplist = gda_entity_get_fields (GDA_ENTITY (FLAT_DATA (module)->manager));
 		else
 			if (module->selector->priv->mode & GNOME_DB_SELECTOR_QALL_FIELDS) 
-				tmplist = gnome_db_query_get_all_fields (GNOME_DB_QUERY (FLAT_DATA (module)->manager));
+				tmplist = gda_query_get_all_fields (GDA_QUERY (FLAT_DATA (module)->manager));
 		if (tmplist && (module->selector->priv->mode & GNOME_DB_SELECTOR_TARGETS)) {
 			GSList *ptr, *newlist = NULL;
 			ptr = tmplist;
 			while (ptr) {
-				if (!IS_GNOME_DB_QF_FIELD (ptr->data) && !IS_GNOME_DB_QF_ALL (ptr->data))
+				if (!GDA_IS_QUERY_FIELD_FIELD (ptr->data) && !GDA_IS_QUERY_FIELD_ALL (ptr->data))
 					newlist = g_slist_prepend (newlist, ptr->data);
 				ptr = g_slist_next (ptr);
 			}
@@ -265,11 +256,11 @@ module_onequery_col_name (Module *module, guint colno)
 /*
  * module_onequery_obj_manager
  *
- * This function is called when a new object is created (GnomeDbQuery). It simply creates a new
+ * This function is called when a new object is created (GdaQuery). It simply creates a new
  * Module (which will be appended to the list of modules of the module for the queries) for 
  * for the contents of that new query.
  *
- * The same applies for GnomeDbTarget objects, with the module for targets.
+ * The same applies for GdaQueryTarget objects, with the module for targets.
  */
 static Module *
 module_onequery_obj_manager (Module *module, GtkTreeIter *iter, GObject *object)
@@ -278,12 +269,12 @@ module_onequery_obj_manager (Module *module, GtkTreeIter *iter, GObject *object)
 
 	g_assert (object);
 
-	if (IS_GNOME_DB_QUERY (object)) {
+	if (GDA_IS_QUERY (object)) {
 		if (module->selector->priv->mode & GNOME_DB_SELECTOR_QVIS_FIELDS) 
 			sub_module = sel_module_onequery_new (module->selector, FALSE, iter, object);
 	}
 
-	if (IS_GNOME_DB_TARGET (object)) {
+	if (GDA_IS_QUERY_TARGET (object)) {
 		if (module->selector->priv->mode & GNOME_DB_SELECTOR_TARGETS) 
 			sub_module = sel_module_onetarget_new (module->selector, FALSE, iter, object);
 		if (module->selector->priv->mode & GNOME_DB_SELECTOR_TARGETS_CTS) 
@@ -302,28 +293,28 @@ module_onequery_model_store_data (Module *module, GtkTreeIter *iter)
 	model = module->selector->priv->model;
 	gtk_tree_model_get (model, iter, OBJ_COLUMN, &obj, -1);
 
-	if (obj && IS_GNOME_DB_QFIELD (obj)) {
-		GnomeDbQfield *field;
+	if (obj && GDA_IS_QUERY_FIELD (obj)) {
+		GdaQueryField *field;
 		const gchar *str1, *str2;
 		gchar *str3;
-		GnomeDbServerDataType *type;
+		GdaDictType *type;
 		
-		field = GNOME_DB_QFIELD (obj);
+		field = GDA_QUERY_FIELD (obj);
 
 		/* data type */
-		type = gnome_db_field_get_data_type (GNOME_DB_FIELD (obj));
+		type = gda_entity_field_get_data_type (GDA_ENTITY_FIELD (obj));
 		if (type)
-			str1 = gnome_db_server_data_type_get_sqlname (type);
+			str1 = gda_dict_type_get_sqlname (type);
 		else
 			str1 = _("-");
 		/* other */
-		str2 = module_onequery_render_qfield_type (GNOME_DB_QFIELD (obj));
-		str3 = gnome_db_renderer_render_as_sql (GNOME_DB_RENDERER (obj), NULL, 0, NULL);
+		str2 = module_onequery_render_qfield_type (GDA_QUERY_FIELD (obj));
+		str3 = gda_renderer_render_as_sql (GDA_RENDERER (obj), NULL, 0, NULL);
 		
 		gtk_tree_store_set (GTK_TREE_STORE (model), iter, 
-				    NAME_COLUMN, str3 ? str3 : gnome_db_base_get_name (GNOME_DB_BASE (obj)),
+				    NAME_COLUMN, str3 ? str3 : gda_object_get_name (GDA_OBJECT (obj)),
 				    EXTRA1_COLUMN, str1,
-				    EXTRA6_COLUMN, str3 ? str3 : gnome_db_base_get_name (GNOME_DB_BASE (obj)),
+				    EXTRA6_COLUMN, str3 ? str3 : gda_object_get_name (GDA_OBJECT (obj)),
 				    EXTRA7_COLUMN, str2,
 				    PIXBUF_COLUMN, QUERY_DATA (module)->field_pixbuf,
 				    ERROR_COLUMN, str3 ? FALSE : TRUE,
@@ -331,20 +322,20 @@ module_onequery_model_store_data (Module *module, GtkTreeIter *iter)
 		if (str3)
 			g_free (str3);
 
-		str1 = gnome_db_base_get_name (GNOME_DB_BASE (field));
-		if (IS_GNOME_DB_QF_FIELD (obj) && (!str1 || !(*str1))) {
+		str1 = gda_object_get_name (GDA_OBJECT (field));
+		if (GDA_IS_QUERY_FIELD_FIELD (obj) && (!str1 || !(*str1))) {
 			gtk_tree_store_set (GTK_TREE_STORE (model), iter, 
 				    NAME_COLUMN, _("Field <no name>"),
 				    -1);
 		}
 	}
 
-	if (obj && IS_GNOME_DB_QUERY (obj)) {
+	if (obj && GDA_IS_QUERY (obj)) {
 		const gchar *str1;
 		gtk_tree_store_set (GTK_TREE_STORE (model), iter, 
-				    EXTRA1_COLUMN, gnome_db_query_get_query_type_string (GNOME_DB_QUERY (obj)),
+				    EXTRA1_COLUMN, gda_query_get_query_type_string (GDA_QUERY (obj)),
 				    -1);
-		str1 = gnome_db_base_get_name (GNOME_DB_BASE (obj));
+		str1 = gda_object_get_name (GDA_OBJECT (obj));
 		if (!str1 || !(*str1)) {
 			gtk_tree_store_set (GTK_TREE_STORE (model), iter, 
 				    NAME_COLUMN, _("Query <no name>"),
@@ -352,10 +343,10 @@ module_onequery_model_store_data (Module *module, GtkTreeIter *iter)
 		}
 	}
 
-	if (obj && IS_GNOME_DB_TARGET (obj)) {
-		const gchar *alias = gnome_db_target_get_alias (GNOME_DB_TARGET (obj));
+	if (obj && GDA_IS_QUERY_TARGET (obj)) {
+		const gchar *alias = gda_query_target_get_alias (GDA_QUERY_TARGET (obj));
 		if (alias && *alias) {
-			gchar *str = g_strdup_printf ("%s AS %s", gnome_db_base_get_name (GNOME_DB_BASE (obj)), alias);
+			gchar *str = g_strdup_printf ("%s AS %s", gda_object_get_name (GDA_OBJECT (obj)), alias);
 			gtk_tree_store_set (GTK_TREE_STORE (model), iter, 
 					    NAME_COLUMN, str, -1);
 			g_free (str);
@@ -365,21 +356,21 @@ module_onequery_model_store_data (Module *module, GtkTreeIter *iter)
 }
 
 static const gchar *
-module_onequery_render_qfield_type (GnomeDbQfield *field)
+module_onequery_render_qfield_type (GdaQueryField *field)
 {
 	GType ftype = G_OBJECT_TYPE (field);
 
-	if (ftype == GNOME_DB_TYPE_QF_ALL)
+	if (ftype == GDA_TYPE_QUERY_FIELD_ALL)
 		return _("entity.*");
-	if (ftype == GNOME_DB_TYPE_QF_FIELD)
+	if (ftype == GDA_TYPE_QUERY_FIELD_FIELD)
 		return _("entity.field");
-	if (ftype == GNOME_DB_TYPE_QF_VALUE) {
-		if (gnome_db_qf_value_is_parameter (GNOME_DB_QF_VALUE (field)))
+	if (ftype == GDA_TYPE_QUERY_FIELD_VALUE) {
+		if (gda_query_field_value_is_parameter (GDA_QUERY_FIELD_VALUE (field)))
 			return _("parameter");
 		else
 			return _("value");
 	}
-	if (ftype == GNOME_DB_TYPE_QF_FUNC) 
+	if (ftype == GDA_TYPE_QUERY_FIELD_FUNC) 
 		return _("function");
 
 	/* for other types */
